/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

export default class FileToUpload {
    static chunkSize = 262144;
    readonly request: XMLHttpRequest;
    readonly uploadUrl: string;
    readonly file: File;
    readonly name: string;
    readonly draftID: string;
    readonly _chunkIdentifier: string;
    private _chunkNumber: number;
    currentChunkStartByte: number;
    currentChunkFinalByte: number;

    constructor(file: File, name: string, draftID : string) {
        this.request = new XMLHttpRequest();
        this.request.onreadystatechange = function(ev: Event) {
            if(this.readyState === XMLHttpRequest.DONE){
                if (this.getResponseHeader('access-token') != null) {
                    console.log(this.getResponseHeader('access-token'))
                    localStorage.setItem('@portalmec/accessToken', this.getResponseHeader('access-token')!)
                }
            }
        }
        this.request.overrideMimeType('application/octet-stream');

        this.file = file;
        this.name = name;
        this.draftID = draftID;
        this.uploadUrl = 'https://api.portalmec.c3sl.ufpr.br/v1/learning_objects/' + draftID + '/chunk'
        this._chunkIdentifier = draftID + '-'  + this.name;
        this._chunkNumber = 0;

        this.currentChunkStartByte = 0;
        this.currentChunkFinalByte = FileToUpload.chunkSize > this.file.size ? this.file.size : FileToUpload.chunkSize;
    }

    uploadFile() {
        this.request.open('POST', this.uploadUrl, true);

        let chunk: Blob = this.file.slice(this.currentChunkStartByte, this.currentChunkFinalByte);  // split the file according to the boundaries

        //set necessary headers
        this.request.setRequestHeader('Content-Range', `bytes ${this.currentChunkStartByte}-${this.currentChunkFinalByte}/${this.file.size}`);
        if (localStorage.getItem('@portalmec/uid') != undefined) {
            this.request.setRequestHeader('uid', localStorage.getItem('@portalmec/uid')!)
        }
        if (localStorage.getItem('@portalmec/clientToken') != undefined) {
            this.request.setRequestHeader('client', String(localStorage.getItem('@portalmec/clientToken')))
        }
        if (localStorage.getItem('@portalmec/accessToken') != undefined) {
            this.request.setRequestHeader('access-token', String(localStorage.getItem('@portalmec/accessToken')))
        }

        this.request.onload = () => {
            const remainingBytes = this.file.size - this.currentChunkFinalByte;

            if(this.currentChunkFinalByte === this.file.size) {
                alert('Yay, upload completed! Chao!');
                return('done');
            } else if (remainingBytes < FileToUpload.chunkSize) {
                // if the remaining chunk is smaller than the chunk size we defined
                this.currentChunkStartByte = this.currentChunkFinalByte;
                this.currentChunkFinalByte = this.currentChunkStartByte + remainingBytes;
            }
            else {
                // keep chunking
                this.currentChunkStartByte = this.currentChunkFinalByte;
                this.currentChunkFinalByte = this.currentChunkStartByte + FileToUpload.chunkSize;
            }

            this._chunkNumber = this._chunkNumber + 1
            this.uploadFile();
        }

        //add attributes
        const formData = new FormData();
        formData.append('_chunkFilename', this.file.name);
        formData.append('_chunkIdentifier', this._chunkIdentifier);
        formData.append('_totalChunks', String(Math.ceil(this.file.size/FileToUpload.chunkSize)));
        formData.append('_chunkSize', String(FileToUpload.chunkSize));
        formData.append('_currentChunkSize', String(this.currentChunkFinalByte - this.currentChunkStartByte));
        formData.append('_chunkNumber', String(this._chunkNumber));
        formData.append('_totalSize', String(this.file.size));
        formData.append('file', chunk);

        this.request.send(formData);// send it now!
    }

}
